# Photon Canon
> An in-depth 3D Monte Carlo simulation toolbox with custom systems of planar mediums, custom beams and detectors

## Table of Contents

- [Project Description](#project-description)
- [Installation](#installation)
- [Usage](#usage)
- [Features](#features)
- [Contributing](#contributing)
- [License](#license)
- [Acknowledgements](#acknowledgements)

## Project Description


### Requirements

- Python 3.12 (others may work, untested)
- Numpy/Cupy
- Pandas
- Scipy

### Install with pip
To install the project and its dependencies, run the following command:

```bash
pip install photon-canon
